@@ -8,12 +8,10 @@ from jsonpath_ng.ext import parse
 
 def fields(args, data):
     f = args.get('fields',[])
-    if not f: return data
-    d = {}
-    for je in f: 
-        for i in parse(je).find(data):
-            d.update({je:i.value})
-    return d
+    if not f:        return data
+    #if len(f) == 1:  return [i.value for i in parse(f[0]).find(data)]
+    #else:            return {je:i.value for je in f for i in parse(je).find(data)}
+    return {je:i.value for je in f for i in parse(je).find(data)}
 
 #####################################
 
